import setuptools


setuptools.setup(
    name='huoyanlib',
    version='2.2.0',
    author='RuiQin Li',
    author_email="2647154420@qq.com",
    description='学而思火焰工作室专属库',
    long_description_content_type="text/markdown",
    url="https://github.com/",
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
)

